==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centre de notificacions</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desancora</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Ancora</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Configuració de les notificacions</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ara mateix</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Fa %1 minuts</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Fa 1 hora</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Fa %1 hores</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ahir</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centre de notificacions</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desancora</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Ancora</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Configuració de les notificacions</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ara mateix</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Fa %1 minuts</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Fa 1 hora</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Fa %1 hores</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ahir</translation>
    </message>
</context>
</TS>
